(game-module "u-bellum"
    (blurb "Standard set of units for the Bellum Aeternum games.")
)

(include "t-bellum")
; ng-features includes ng-weird, which is used here
(include "ng-features")

(unit-type ruins
    (name "Ruins")
    (char "0")
    (help "The gutted remnants of a town or city.")
    (notes (
        "The remnants of a town or city, now crumbling."
        "Can be used as a crude base and hideout by land forces."
    ))
    (image-name "city20-rubble")
    (point-value 0)
;   (action-priority 0)
    (acp-per-turn 1)
    (hp-max 10)
    (acp-to-disband 1)
    (hp-per-disband 1)
    (vision-range 0)
    (capacity 1)
    (cp 0)
    (unit-growth-chance 0)
    (ai-war-garrison 0)
)

(unit-type town
    (name "Town")
    (char "1")
    (help "Small city.")
    (notes (
        "Small city with only limited quartering capacity."
        "Short airstrip and minimal dock facilities."
        "Baseline military production and training capabilities."
    ))
    (description-format (side " town " name " at " position))
    (image-name "town20")
    (point-value 5)
;   (action-priority 5)
    (acp-per-turn 1)
    (hp-max 50)
    (hp-recovery 1.00)
    (acp-damage-effect (
        (0 0) (25 0)
        (26 1) (50 1)
    ))
    (wrecked-type ruins)
    (capacity 2)
    (cp 52)
    (cp-to-self-build 1)
    (cp-per-self-build 1)
    (see-terrain-if-captured 0)
    (unit-growth-chance 30)
    (ai-war-garrison 1)
)

(unit-type city
    (name "City")
    (char "2")
    (help "Medium city.")
    (notes (
        "Medium city with significant quartering capacity."
        "Small airbase and sizable dock facilities."
        "Large military academy and camp."
        "Strong industrial centers."
    ))
    (description-format (side " city " name " at " position))
    (image-name "city20")
    (point-value 20)
;   (action-priority 4)
    (acp-per-turn 4)
    (acp-max 4)
    (hp-max 200)
    (hp-recovery 5.00)
    (acp-damage-effect (
        (0 1) (25 1)
        (26 2) (50 2)
        (51 3) (150 3)
        (151 4) (200 4)
    ))
    (wrecked-type town)
    (capacity 6)
    (see-terrain-if-captured 20)
    (unit-growth-chance 10)
    (ai-war-garrison 3)
    (minimal-sea-for-docks 50)
)

(unit-type citadel
    (name "Grand Citadel")
    (char "3")
    (help "Special fortified city.")
    (notes (
        "Special fortified city saturated with military-industrial power."
        "Multiple large airbases and shipyards."
        "Multiple military academies and camps."
        "Packed with wartime industrial muscle."
        "Alternative government center."
    ))
    (description-format (side " grand citadel " name " at " position))
    (image-name "city20")
    (point-value 70)
;    (action-priority 2)
    (acp-per-turn 8)
    (acp-max 8)
    (hp-max 500)
    (hp-recovery 15.00)
    (acp-damage-effect (
        (0 0) (25 0)
        (26 1) (50 1)
        (51 2) (75 2)
        (76 3) (100 3)
        (101 4) (125 4)
        (126 5) (150 5)
        (151 6) (200 6)
        (201 7) (250 7)
        (251 8) (500 8) 
    ))
    (wrecked-type ruins)
    (capacity 6)
    (cp 140)
    (cp-to-self-build 1)
    (cp-per-self-build 1)
    (see-terrain-if-captured 100)
    (unit-growth-chance 0)
    (ai-war-garrison 6)
    (minimal-sea-for-docks 50)
)

(unit-type metropolis
    (name "Metropolis")
    (char "4")
    (help "Large city.")
    (notes (
        "Large city with massive quartering capacity."
        "Large airbase and dock facilities and shipyard."
        "Multiple military academies and camps."
        "Massive industrial power."
    ))
    (description-format (side " metropolis " name " at " position))
    (image-name "city20")
    (point-value 100)
;   (action-priority 3)
    (acp-per-turn 8)
    (acp-max 8)
    (hp-max 500)
    (hp-recovery 10.00)
    (acp-damage-effect (
        (0 4) (50 4)
        (51 5) (100 5)
        (101 6) (250 6)
        (251 7) (400 7)
        (401 8) (500 8)
    ))
    (wrecked-type city)
    (capacity 6)
    (see-terrain-if-captured 100)
    (unit-growth-chance 0)
    (ai-war-garrison 6)
    (minimal-sea-for-docks 50)
)

(unit-type capitol
    (name "Capitol")
    (char "@")
    (help "Governing metropolis.")
    (notes (
        "Large city with massive quartering capacity."
        "Multiple large airbases and shipyards."
        "Multiple military academies and camps."
        "Massive industrial power."
        "Defended by fanatical paramilitary forces."
        "Government center."
    ))
    (description-format (side " capitol " name " at " position))
;    (image-name "crown")
    (image-name "parthenon")
    (can-be-self true)
    (start-with 1)
    (point-value 200)
;   (action-priority 1)
    (acp-per-turn 12)
    (acp-max 12)
    (hp-max 1000)
    (hp-recovery 15.00)
    (acp-damage-effect (
        (0 1) (50 1)
        (51 2) (100 2)
        (101 3) (150 3)
        (151 4) (200 4)
        (201 5) (250 5)
        (251 6) (350 6)
        (351 7) (400 7)
        (451 8) (500 8)
        (501 9) (550 9)
        (551 10) (650 10)
        (651 11) (700 11)
        (701 12) (1000 12)
    ))
    (wrecked-type ruins)
    (capacity 6)
;    (unit-growth-chance 80)
    (unit-growth-chance 2)
    (ai-war-garrison 6)
    (minimal-sea-for-docks 50)
)

(define city-u* (capitol metropolis citadel city town ruins))
(add city-u* independent-growth-chance 0)
(add city-u* unit-takeover-chance 0)
(add city-u* independent-takeover-chance 0)
(add city-u* spur-chance 0)
(add city-u* spur-range 0)
(add (town ruins) spur-chance (100 50))
(add (town ruins) spur-range 15)
(add city-u* colonizer true)
(add city-u* minimal-sea-for-docks 50)
(add town auto-upgrade-to city)
(add city auto-upgrade-to metropolis)

(unit-type forts
    (name "Fortifications")
    (char "|")
    (help "Trenches, pillboxes, small bunkers, earthworks, etc....")
;    (image-name "fort")
    (image-name "spec-keep")
    (point-value 1)
;   (action-priority 11)
    (acp-per-turn 0)
    (hp-max 20)
    (capacity 2)
    (cp 8)
    (ai-war-garrison 1)
)

(unit-type base
    (name "Base")
    (char "/")
    (help "Command center, depot, staging point, et cetera.")
    (image-name "airbase")
    (point-value 10)
;    (action-priority 8)
    (acp-per-turn 4)
    (acp-max 4)
    (acp-damage-effect (
        (0 0) (5 0)
        (6 1) (10 1)
        (11 2) (20 2)
        (21 3) (30 3)
        (31 4) (35 4)
    ))
    (hp-max 35)
    (capacity 6)
    (cp 26)
    (see-terrain-if-captured 100)
    (ai-war-garrison 4)
)

(unit-type shipyard
    (name "Sea Base")
    (char "\\")
    (help "Shipyard and naval command center.")
    (image-name "anchor")
    (point-value 10)
;    (action-priority 8)
    (acp-per-turn 4)
    (acp-max 4)
    (acp-damage-effect (
        (0 0) (5 0)
        (6 1) (10 1)
        (11 2) (20 2)
        (21 3) (30 3)
        (31 4) (35 4)
    ))
    (hp-max 35)
    (capacity 6)
    (cp 26)
    (see-terrain-if-captured 100)
    (ai-war-garrison 0)
    (minimal-sea-for-docks 50)
)

(add (forts base shipyard) assign-number true)

(define facility-u* (append city-u* forts base shipyard))
(add facility-u* namer "generic-names")
(add facility-u* facility true)
(add facility-u* advanced true)
(add ruins advanced false)
(add facility-u* acp-to-move 1000) 
(add facility-u* speed 0)
(add facility-u* free-mp 0)
(add facility-u* acp-to-fire 1)
(add (ruins forts) acp-to-fire 0)
(add facility-u* see-always true)
(add facility-u* ai-peace-garrison 0)
(add facility-u* minimal-size-goal 0)

(unit-type infantry
    (name "Infantry")
    (char "i")
    (help "Marches and fights on land. Captures. Entrenches.")
    (notes (
        "Uses motor vehicles to move quickly on road systems."
        "Versatile on all land terrain."
        "Can take good advantage of terrain cover."
    ))
    (image-name "trident-alpine-troops")
    (point-value 0)
;   (action-priority 101)
    (acp-per-turn 4)
    (acp-max 4)
    (acp-damage-effect ((0 0) (1 1) (2 1) (3 2) (4 2) (5 4)))
    (speed 100)
    (acp-to-fire 0)	
    (hp-max 5)
    (capacity 0)
    (cp 16)
    (ai-tactical-range 8)
)

(unit-type mechinf
    (name "Mech Infantry")
    (char "y")
    (help "Infantry with APC's, half-tracks, and light artillery.")
;    (image-name "halftrack")
    (image-name "pg240")
    (point-value 0)
;   (action-priority 111)
    (acp-per-turn 5)
    (acp-max 5)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 3) (5 4) (6 5)))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 6)
    (capacity 0)
    (cp 16)
    (ai-tactical-range 8)
)

(unit-type cavalry
    (name "Cavalry")
    (char "c")
    (help "Light armor, plus other fighting vehicles and scouts.")
;    (image-name "maultier")
    (image-name "pg235")
    (point-value 1)
;   (action-priority 131)
    (acp-per-turn 5)
    (acp-max 5)
    (acp-damage-effect (
        (0 0) (1 1) (2 1) (3 2) (4 2) (5 3) (6 3) (7 4) (9 4) (10 5) (12 5)
    ))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 12)
    (vision-range 2)
    (capacity 0)
    (cp 18)
    (ai-tactical-range 10)
)

(unit-type armor
    (name "Armor")
    (char "r")
    (help "A whole bunch of badass tanks.")
;    (image-name "tiger-1")
    (image-name "pg34")
    (point-value 0)
;   (action-priority 121)
    (acp-per-turn 6)
    (acp-max 6)
    (acp-damage-effect (
        (0 0) (1 1) (2 1) (3 2) (4 2) (5 3) (6 3)
        (7 4) (9 4) (10 5) (12 5) (13 6) (16 6)
    ))
    (speed 50)
    (acp-to-fire 1)
    (range 2)
    (fire-angle-max 100)
    (hp-max 16)
    (capacity 0)
    (cp 16)
    (ai-tactical-range 8)
)

(unit-type marines
    (name "Marines")
    (char "m")
    (help "Likes making a splash. Captures. Entrenches.")
;    (image-name "elite")
    (image-name "trident-marines")
    (point-value 0)
;   (action-priority 141)
    (acp-per-turn 5)
    (acp-max 5)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 4) (5 5) (8 5)))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 8)
    (capacity 0)
    (cp 22)
    (ai-tactical-range 8)
)

(unit-type paratroops
    (name "Paratroopers")
    (char "p")
    (help "Likes jumping out of aircraft. Captures.")
    (image-name "trident-paratroopers")
    (point-value 1)
;   (action-priority 201)
    (acp-per-turn 4)
    (acp-max 4)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 4) (6 4)))
    (speed 100)
    (acp-to-fire 0)
    (hp-max 6)
    (capacity 0)
    (cp 26)
    (ai-tactical-range 8)
)

(unit-type artillery
    (name "Artillery")
    (char "a")
    (help "Howitzers and heavy field cannon.")
;    (image-name "howitzer")
    (image-name "trident-howitzer")
    (point-value 1)
;   (action-priority 192)
    (acp-per-turn 4)
    (acp-max 4)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 4)))
    (speed 100)
    (acp-to-fire 1)
    (range 3)
    (hit-falloff-range 2)
    (fire-angle-max 100)
    (hp-max 4)
    (capacity 0)
    (cp 20)
    (ai-tactical-range 8)
)

(unit-type aaa
    (name "AA Battery")
    (char "A")
    (help "Light field cannon and anti-aircraft weapons.")
;    (image-name "flak")
    (image-name "trident-artillery")
    (point-value 1)
;   (action-priority 193)
    (acp-per-turn 4)
    (acp-max 4)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 4)))
    (speed 100)
    (acp-to-fire 1)
    (range 2)
    (fire-angle-max 100)
    (hp-max 4)
    (capacity 0)
    (cp 20)
    (ai-tactical-range 8)
)

(unit-type field-hq
    (name "Field HQ")
    (char "x")
    (help "Mobile command and control center.")
;    (image-name "corps-hq")
    (image-name "legion")
    (point-value 10)
;   (action-priority 91)
    (acp-per-turn 5)
    (acp-max 5)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 3) (5 4) (7 4) (8 5)))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 8)
    (capacity 0)
    (cp 20)
    (ai-tactical-range 10)
)

(unit-type germinator
    (name "Germinator")
    (char "g")
    (help "Harvests settlers. Seeds new towns and citadels.")
;    (image-name "engr")
    (image-name "trident-settlers")
    (point-value 10)
;   (action-priority 6)
    (acp-per-turn 6)
    (acp-max 6)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 4) (4 6)))
    (speed 50)
    (acp-to-fire 0)
    (hp-max 4)
    (capacity 0)
    (cp 32)
    (colonizer true)
    (ai-tactical-range 3)
)

(unit-type engineers
    (name "Engineers")
    (char "n")
    (help "Builds and repairs bases. Removes minefields.")
    (image-name "trident-engineers")
    (point-value 5)
;   (action-priority 7)
    (acp-per-turn 4)
    (acp-max 4)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 4)))
    (speed 75)
    (acp-to-fire 0)
    (hp-max 4)
    (capacity 0)
    (cp 28)
    (colonizer true)
    (ai-tactical-range 3)
)

(define land-u* (infantry mechinf cavalry armor marines paratroops 
    artillery aaa field-hq germinator engineers))
(add land-u* assign-number true)
(add land-u* ground true)

(unit-type shipwreck
    (name "Shipwreck")
    (char ".")	; Same as the sea for an ncurses game.
    (help "A ruined or beached ship.")
;    (image-name "block")
    (image-name "flag-robot")
    (point-value 0)
;   (action-priority 0)
    (acp-per-turn 1)
    (speed 0)
    (acp-to-fire 0)
    (hp-max 4)
    (acp-to-disband 1)
    (hp-per-disband 1)
    (vision-range -1)
    (capacity 0)
    (cp 0)
)

(unit-type transports
    (name "Sea Transports")
    (char "T")
    (help "Carries land units to foreign shores.")
    (image-name "ap")
    (point-value 0)
;   (action-priority 151)
    (acp-per-turn 3)
    (acp-max 3)
    (acp-damage-effect ((0 0) (1 1) (4 1) (5 2) (15 2) (16 3)))
    (speed 100)
    (acp-to-fire 0)
    (hp-max 16)
    (capacity 6)
    (cp 20)
    (ai-tactical-range 40)
)

(unit-type torp-boats
    (name "Torpedo Boats")
    (char "O")
    (help "Attempts to torpedo larger vessels. Can also deploy mines.")
;    (image-name "pt")
    (image-name "pg200")
    (point-value 0)
;   (action-priority 161)
    (acp-per-turn 4)
    (acp-max 4)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 4)))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 4)
    (capacity 0)
    (cp 8)
;    (colonizer true)
    (ai-tactical-range 8)
)

(unit-type patrol-ship
    (name "Patrol Ship")
    (char "P")
    (help "Patrols. Lays and sweeps mines.")
;    (image-name "pt")
    (image-name "pg200")
    (point-value 0)
;   (action-priority 162)
    (acp-per-turn 3)
    (acp-max 3)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3)))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 3)
    (capacity 0)
    (cp 8)
    (colonizer true)
    (ai-tactical-range 8)
)

(unit-type destroyer
    (name "Destroyer")
    (char "D")
    (help "Escorts other ships. Hunts subs, small ships, and boats.")
    (image-name "dd")
    (point-value 0)
;   (action-priority 171)
    (acp-per-turn 3)
    (acp-max 3)
    (acp-damage-effect ((0 0) (1 1) (2 1) (3 2) (4 2) (5 3) (6 3)))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 6)
    (capacity 0)
    (cp 16)
    (ai-tactical-range 10)
)

(unit-type frigate
    (name "Frigate")
    (char "F")
    (help "A frigate or light cruiser. Escorts other ships.")
    (image-name "cl")
    (point-value 0)
;   (action-priority 172)
    (acp-per-turn 6)
    (acp-max 6)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 4) (5 4) (6 6) (8 6)))
    (speed 50)
    (acp-to-fire 1)
    (hp-max 8)
    (capacity 0)
    (cp 18)
    (ai-tactical-range 10)
)

(unit-type cruiser
    (name "Cruiser")
    (char "C")
    (help "A heavy cruiser or battle cruiser.")
    (image-name "ca")
    (point-value 1)
;   (action-priority 181)
    (acp-per-turn 8)
    (acp-max 8)
    (acp-damage-effect (
        (0 0) (1 1) (2 2) (3 3) (5 3) (6 4) (8 4) (9 5) (10 5) 
        (11 6) (12 6) (13 7) (14 7) (15 8) (20 8)
    ))
    (speed 50)
    (acp-to-fire 1)
    (range 2)
    (fire-angle-max 100)
    (hp-max 20)
    (wrecked-type shipwreck)
    (capacity 0)
    (cp 18)
    (ai-tactical-range 12)
)

(unit-type ccruiser
    (name "Command Cruiser")
    (char "X")
    (help "A command and control ship.")
    (image-name "ca")
    (point-value 10)
;   (action-priority 92)
    (acp-per-turn 8)
    (acp-max 8)
    (acp-damage-effect (
        (0 0) (1 1) (2 2) (3 3) (4 4) (5 5) (6 5) 
        (7 6) (8 6) (9 7) (10 7) (11 8) (14 8)
    ))
    (speed 50)
    (acp-to-fire 1)
    (hp-max 14)
    (wrecked-type shipwreck)
    (capacity 0)
    (cp 24)
    (ai-tactical-range 16)
)

(unit-type battleship
    (name "Battleship")
    (char "B")
    (help "The king of warships.")
    (image-name "bb")
    (point-value 10)
;   (action-priority 191)
    (acp-per-turn 8)
    (acp-max 8)
    (acp-damage-effect (
        (0 0) (1 1) (2 2) (3 3) (5 3) (6 4) (8 4) (9 5) (11 5) 
        (12 6) (15 6) (16 7) (19 7) (20 8) (30 8)
    ))
    (speed 50)
    (acp-to-fire 1)
    (range 3)
    (hit-falloff-range 2)
    (fire-angle-max 100)
    (hp-max 30)
    (wrecked-type shipwreck)
    (capacity 0)
    (cp 28)
    (ai-tactical-range 16)
)

(unit-type ecarrier
    (name "Escort Carrier")
    (char "E")
    (help "Carries, at most, 1 wing of light warplanes.") 
    (image-name "cve-shoho")
    (point-value 5)
;   (action-priority 241)
    (acp-per-turn 3)
    (acp-max 3)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 3)))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 4)
    (wrecked-type shipwreck)
    (capacity 1)
    (cp 16) 
    (ai-tactical-range 12)
    (ai-war-garrison 0)
    (ai-peace-garrison 1)
)

(unit-type lcarrier
    (name "Light Carrier")
    (char "L")
    (help "Carries up to 3 wings of light warplanes.")
    (image-name "cv-saratoga")
    (point-value 10)
;   (action-priority 242)
    (acp-per-turn 4)
    (acp-max 4)
    (acp-damage-effect ((0 0) (1 1) (2 2) (3 3) (4 4) (6 4)))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 6)
    (wrecked-type shipwreck)
    (capacity 3)
    (cp 22)
    (ai-tactical-range 16)
    (ai-war-garrison 0)
    (ai-peace-garrison 3)
)

(unit-type carrier
    (name "Fleet Carrier")
    (char "V")
    (help "Carries up to 6 wings of light warplanes.")
    (image-name "cv")
    (point-value 20)
;   (action-priority 243)
    (acp-per-turn 8)
    (acp-max 8)
    (acp-damage-effect (
        (0 0) (1 1) (2 2) (3 3) (4 4) (5 5) (6 6) 
        (7 6) (8 7) (10 7) (11 8) (14 8)
    ))
    (speed 50)
    (acp-to-fire 1)
    (hp-max 14)
    (wrecked-type shipwreck)
    (capacity 6)
    (cp 34)
    (ai-tactical-range 20)
    (ai-war-garrison 0)
    (ai-peace-garrison 6)
)

(unit-type submarine
    (name "Submarine")
    (char "S")
    (help "Sneaks around underwater and destroys ships.")
    (image-name "sub")
    (point-value 10)
;   (action-priority 211)
    (acp-per-turn 3)
    (acp-max 3)
    (acp-damage-effect ((0 0) (1 1) (3 1) (4 3)))
    (speed 100)
    (acp-to-fire 1)
    (hp-max 4)
    (capacity 1)
    (cp 24)
    (ai-tactical-range 12)
)

(define carrier-u* (ecarrier lcarrier carrier))
(define sea-u* (append transports torp-boats patrol-ship destroyer frigate
    cruiser ccruiser battleship carrier-u* submarine))
(add sea-u* fire-angle-max 75)
(add sea-u* assign-number true)
(add sea-u* naval true)

(unit-type cargo-planes
    (name "Cargo Planes")
    (char "t")
    (help "Carries supplies all over. Drops paratroopers and SF men.")
    (image-name "4e")
    (point-value 1)
;   (action-priority 203)
    (acp-per-turn 20)
    (acp-max 20)
    (acp-damage-effect ((0 0) (1 12) (2 12) (3 16) (9 16) (10 20)))
    (acp-to-fire 0)
    (hp-max 10)
    (vision-range 2)
    (capacity 2)
    (cp 20)
    (ai-tactical-range 20)
)

(unit-type fighters
    (name "Fighters")
    (char "f")
    (help "Intercepts air units. Strafes land units.")
    (image-name "fighter")
    (point-value 1)
;   (action-priority 211)
    (acp-per-turn 24)
    (acp-max 24)
    (acp-damage-effect ((0 0) (1 20) (4 20) (5 24) (25 24)))
    (acp-to-fire 0)
    (hp-max 25)
    (vision-range 2)
    (capacity 0)
    (cp 20)
    (ai-tactical-range 8)
)

(unit-type efighters
    (name "Escort Fighters")
    (char "e")
    (help "Escorts cargo planes and long-range bombers.")
    (image-name "fighter")
    (point-value 1)
;   (action-priority 231)
    (acp-per-turn 24)
    (acp-max 24)
    (acp-damage-effect ((0 0) (1 20) (6 20) (7 24) (32 24)))
    (acp-to-fire 0)
    (hp-max 32)
    (vision-range 2)
    (capacity 0)
    (cp 20)
    (ai-tactical-range 12)
)

(unit-type dive-bombers
    (name "Dive Bombers")
    (char "d")
    (help "Performs pinpoint bombing on land and sea targets.")
    (image-name "fighter")
    (point-value 1)
;   (action-priority 221)
    (acp-per-turn 24)
    (acp-max 24)
    (acp-damage-effect ((0 0) (1 16) (2 16) (3 20) (9 20) (10 24)))
    (acp-to-fire 0)
    (acp-to-detonate 1)
    (hp-per-detonation 10)
    (hp-max 10)
    (vision-range 2)
    (capacity 0)
    (cp 20)
    (ai-tactical-range 8)
)

(unit-type torp-bombers
    (name "Torp Bombers")
    (char "o")
    (help "Attempts to torpedo naval units.")
    (image-name "fighter")
    (point-value 1)
;   (action-priority 221)
    (acp-per-turn 24)
    (acp-max 24)
    (acp-damage-effect ((0 0) (1 16) (2 16) (3 20) (9 20) (10 24)))
    (acp-to-fire 1)
    (acp-to-detonate 1)
    (hp-per-detonation 10)
    (hp-max 10)
    (vision-range 2)
    (capacity 0)
    (cp 20)
    (ai-tactical-range 8)
)

(unit-type bombers
    (name "Bombers")
    (char "b")
    (help "Drops lots of bombs but with only moderate accuracy.")
    (image-name "4e")
    (point-value 1)
;   (action-priority 232)
    (acp-per-turn 20)
    (acp-max 20)
    (acp-damage-effect ((0 0) (1 12) (5 12) (6 16) (31 16) (32 20)))
    (acp-to-fire 0)
    (hp-max 32)
    (vision-range 2)
    (capacity 0)
    (cp 24)
    (ai-tactical-range 20)
)

(unit-type spy-planes
    (name "Spy Planes")
    (char "s")
    (help "Provides high altitude surveilance.")
    (image-name "2e")
    (point-value 1)
;   (action-priority 241)
    (acp-per-turn 32)
    (acp-max 32)
    (acp-damage-effect ((0 0) (1 32) (6 32)))
    (acp-to-fire 0)
    (hp-max 6)
    (vision-range 3)
    (capacity 0)
    (cp 24)
    (ai-tactical-range 25)
)

#|
(unit-type cargo-choppers
    (name "Cargo Helos")
    (char "{")
    (help "Ferries light land units around.")
    (image-name "cargo-chopper")
    (point-value 1)
;   (action-priority 93)
    (acp-per-turn 10)
    (acp-to-fire 0)
    (hp-max 6)
    (capacity 2)
    (cp 20)
)

(unit-type attack-choppers
    (name "Attack Helos")
    (char "}")
    (help "Rips land vehicles to pieces and mows down personnel.")
    (image-name "helicopter")
    (point-value 1)
;   (action-priority 94)
    (acp-per-turn 12)
    (acp-to-fire 3)
    (hp-max 10)
    (capacity 0)
    (cp 20)
)
|#

(define air-u* (
    cargo-planes fighters efighters
    dive-bombers torp-bombers bombers
    spy-planes #| cargo-choppers attack-choppers |#
))
(add air-u* assign-number true)
(add air-u* air true)
(add air-u* speed 100)

(unit-type landmines
    (name "Minefield")
    (char "*")
    (help "Blows up personnel and vehicles on land.")
    (image-name "minefield")
;   (action-priority 51)
    (acp-per-turn 1)
    (speed 100)
    (acp-to-detonate 1)
    (hp-per-detonation 1)
    (hp-max 6)
    (acp-to-disband 1)
    (hp-per-disband 2)
    (cp 4)
    (ground true)
)

(unit-type seamines
    (name "Sea Mines")
    (char "&")
    (help "Blows up ships.")
    (image-name "minefield")
;   (action-priority 51)
    (acp-per-turn 1)
    (speed 100)
    (acp-to-detonate 1)
    (hp-per-detonation 1)
    (hp-max 6)
    (acp-to-disband 1)
    (hp-per-disband 2)
    (cp 4)
    (naval true)
)

(define mine-u* (landmines seamines))
(add mine-u* assign-number true)
(add mine-u* point-value 0)
;(add mine-u* advanced true)
(add mine-u* vision-range 0)
(add mine-u* capacity 0)

(define immobile-u* (append facility-u* mine-u*))
(define mobile-u* (append land-u* sea-u* air-u*))

(define aaa-u* (aaa frigate))

;; Unit-Terrain and Unit-Material Interactions

(table independent-density
    ; Default: 0 ppdk
    ((metropolis city town ruins) plains (30 180 1000 90))
    ((metropolis city town ruins) swamp (6 36 400 18))
    ((city town ruins) forest (16 500 8))
    ((metropolis city town ruins) desert (12 72 800 36))
    ((city town ruins) mountains (8 400 4))
    (u* barrier 0)      ; NOTE: Leave this at end of table.
)

(table favored-terrain
    ; Default: 100%
    (u* t* 0)
    (capitol plains 100)
    (city land-t* 30)
    (town land-t* 40)
    (base land-t* 40)
    (shipyard coast 100)
    (infantry (plains desert) 90)
    (mechinf (plains desert) 90)
    (armor (plains desert) 90)
    (marines (plains desert) 90)
    (marines (coast lake) 10)
    (germinator (plains desert) 100)
    (engineers (plains desert) 100)
    (u* glaciers 0)
    (u* barrier 0)      ; NOTE: Leave this at end of table.
)

(table vanishes-on
    ; Default: false
    (facility-u* water-t* true)
    (city-u* lake false)
    (shipyard coast false)
    (landmines water-t* true)
    (seamines land-t* true)
    (u* barrier true)	; NOTE: Should always be last item.
)

(table wrecks-on
    ; Default: false
    ; NOTE: See all-humans variant.
)

(table terrain-capacity-x
    ; Default: 0
    (air-u* t* 2)
)

(table unit-size-in-terrain
    ; Default: 1
    (u* t* 1000)
    (city-u* land-t* 16)
    (town land-t* 13)
    (ruins land-t* 13)
    (forts land-t* 8)
    (base land-t* 13)
    (shipyard coast 13) 
    (land-u* t* 1)
    (land-u* water-t* 1000)
    ((marines engineers) (coast lake) 1)
    (marines sea 1)
    (shipwreck water-t* 1)
    (sea-u* water-t* 1)
    (air-u* t* 1)
    (landmines land-t* 7)
    (seamines water-t* 7)
    (u* barrier 1000)	; NOTE: Should always be last item.
)

(table unit-storage-x
    ; Default: 0
    (capitol fuel1 1500)
    (metropolis fuel1 1000)
    (citadel fuel1 1000)
    (city fuel1 250)
    (town fuel1 50)
    (forts fuel1 20)
    (base fuel1 500)
    (shipyard fuel1 300)
    ((mechinf armor marines artillery aaa) fuel1 14)
    ((cavalry field-hq germinator engineers) fuel1 20)
    (transports fuel1 20)
    (ecarrier fuel1 50)
    (lcarrier fuel1 150)
    (carrier fuel1 400)
    ; Aircraft fuel ranges are base-12.
    ((cargo-planes bombers) fuel1 60) 
    ((fighters dive-bombers torp-bombers) fuel1 24)
    (efighters fuel1 48)
    (spy-planes fuel1 64)
    (capitol fuel2 200)
    (metropolis fuel2 180)
    (citadel fuel2 150)
    (city fuel2 100)
    (town fuel2 20)
    (shipyard fuel2 200)
    (transports fuel2 150)
    (torp-boats fuel2 20)
    (patrol-ship fuel2 40)
    (destroyer fuel2 50)
    (frigate fuel2 80)
    (cruiser fuel2 100)
    (ccruiser fuel2 120)
    (battleship fuel2 150)
    (ecarrier fuel2 80)
    (lcarrier fuel2 120)
    (carrier fuel2 150)
    (submarine fuel2 150)
    (capitol supplies 2000)
    (metropolis supplies 2000)
    (citadel supplies 2000)
    (city supplies 500)
    (town supplies 150)
    (ruins supplies 10)
    (forts supplies 100)
    ((base shipyard) supplies 1000)
    (infantry supplies 6)
    ((mechinf cavalry armor marines artillery aaa) supplies 8)
    (paratroops supplies 3)
    (field-hq supplies 12)
    (germinator supplies 1000)
    (engineers supplies 100)
    (transports supplies 600)
    (torp-boats supplies 6)
    (patrol-ship supplies 15)
    (destroyer supplies 30)
    (frigate supplies 45)
    (cruiser supplies 60)
    (ccruiser supplies 70)
    (battleship supplies 90)
    (ecarrier supplies 50)
    (lcarrier supplies 80)
    (carrier supplies 120)
    (submarine supplies 120)
    (cargo-planes supplies 40)
    (capitol equipment 2000)
    (metropolis equipment 1500)
    (citadel equipment 1500)
    (city equipment 400)
    (town equipment 100)
    (base equipment 500)
    (shipyard equipment 500)
    (engineers equipment 40)
    (capitol vehicles 1000)
    (metropolis vehicles 800)
    (citadel vehicles 800)
    (city vehicles 200)
    (town vehicles 50)
    (base vehicles 400)
    (shipyard vehicles 250)
    ((capitol citadel) cnc 1000)
    (metropolis cnc 200)
    (city cnc 60)
    (town cnc 15)
    (forts cnc 20)
    (base cnc 300)
    (shipyard cnc 100)
    ((infantry mechinf aaa) cnc 8)
    ((armor artillery) cnc 10)
    ((cavalry marines paratroops engineers) cnc 12)
    ((field-hq germinator) cnc 200)
    ((transports cruiser ecarrier) cnc 40)
    ((torp-boats patrol-ship) cnc 20)
    ((destroyer frigate) cnc 30)
    ((ccruiser carrier) cnc 200)
    ((battleship lcarrier submarine) cnc 100)
    (air-u* cnc 50)
    ((capitol citadel) recruits 50)
    (metropolis recruits 40)
    (city recruits 15)
    (town recruits 5)
    ((base shipyard) recruits 250)
    ((capitol citadel) pilots 75)
    (metropolis pilots 60)
    (city pilots 15)
    (town pilots 5)
    (base pilots 150)
    (shipyard pilots 15)
    (capitol settlers 50)
    (metropolis settlers 40)
    (city settlers 10)
    (town settlers 3)
    (germinator settlers 110)
#|
    ((capitol metropolis) city-points 800)
    (citadel city-points 600)
    (city city-points 400)
    (town city-points 200)
|#
)

(table unit-initial-supply
    ; Default: 0
    (u* m* 32000)
    (capitol cnc 1000)
    (metropolis cnc 200)
    (city cnc 40)
    (town cnc 10)
    (forts cnc 20)
    (base cnc 200)
    (shipyard cnc 75)
    (capitol settlers 50)
    (metropolis settlers 40)
    (city settlers 10)
    (town settlers 3)
#|
    ((capitol metropolis) city-points 410)
    (citadel city-points 310)
    (city city-points 210)
    (town city-points 110)
|#
)

(table base-production
    ; Default: 0
    ((capitol metropolis citadel) fuel1 200)
    (city fuel1 120)
    (town fuel1 30)
    (shipyard fuel2 40)
    ((capitol metropolis citadel) supplies 200)
    (city supplies 100)
    (town supplies 25)
    ((capitol metropolis citadel) equipment 100)
    (city equipment 40)
    (town equipment 10)
    ((capitol metropolis citadel) vehicles 40)
    (city vehicles 20)
    (town vehicles 5)
    (capitol cnc 200)
    (metropolis cnc 20)
    (citadel cnc 100)
    (city cnc 5)
    (town cnc 0)
    (base cnc 35)
    (shipyard cnc 35)
    (field-hq cnc 35)
    ((ccruiser carrier) cnc 35)
    (battleship cnc 15)
    ((capitol metropolis citadel) recruits 20)
    (city recruits 5)
    (town recruits 1)
    ((capitol metropolis citadel base) pilots 3)
    ((capitol metropolis) settlers 20)
    (city settlers 4)
    (town settlers 1)
#|
    (city-u* city-points 1)
    (ruins city-points 0)
|#
)

(table base-consumption
    ; Default: 0
    (air-u* fuel1 4)		; Help them crash if they get stranded.
    (land-u* supplies 1)
    ; TODO: SF guys don't consume supplies.
    (sea-u* supplies 1)
    (transports supplies 3)
    (cargo-planes supplies 2)
    (forts supplies 1)
    (u* cnc 1)
    ((capitol metropolis citadel base) recruits 3)
    (ruins m* 0)
    (landmines m* 0)
    (seamines m* 0)
)

(table gives-to-treasury
    ; Default: false
)

(table takes-from-treasury
    ; Default: false
)

(table consumption-as-occupant
    ; Default: 100%
    (air-u* fuel1 0)		; Don't crash if landed.
    (land-u* cnc 0)		; Transport/facility absorbs cost.
)

(table hp-per-starve
    ; Default: 0
    (air-u* fuel1 10.00)	; Crash without fuel.
    (land-u* supplies 2.00)	; Starve to death.
)

(table in-length
    ; Default: 0
    ((capitol citadel) m* 50)
    ((metropolis base shipyard) m* 40)
    (city m* 15)
    (town m* 10)
    (forts (fuel1 supplies) 6)
    (land-u* (fuel1 supplies) 3)
    (field-hq (fuel1 supplies) 5)
    (transports (fuel1 supplies) 3)
    (sea-u* supplies 2)
    (facility-u* cnc 50)
    ((capitol citadel ruins base shipyard) cnc 0)
    (forts cnc 10)
    ((infantry mechinf armor artillery aaa engineers) cnc 8)
    ((cavalry marines paratroops) cnc 10)
    (field-hq cnc 0)
    (germinator cnc 50)
    ((transports destroyer frigate) cnc 15)
    ((torp-boats patrol-ship) cnc 10)
    ((cruiser ecarrier) cnc 20)
    ((lcarrier submarine) cnc 25)
    ((ccruiser battleship carrier) cnc 0)
    (air-u* cnc 25)
    (city-u* settlers 0)
    (germinator settlers 50)
)

(table out-length
    ; Default: 0
    ((capitol citadel) m* 50)
    ((metropolis base shipyard) m* 40)
    (city m* 15)
    (town m* 10)
    (transports (fuel1 supplies) 3)
    ((capitol citadel base shipyard) cnc 50)
    (forts cnc 5)
    (land-u* cnc 2)
    (field-hq cnc 15)
    (sea-u* cnc 2)
    ((ccruiser carrier) cnc 15)
    ((battleship lcarrier) cnc 10)
    (air-u* cnc 10)
)

(table mp-to-enter-terrain
    (u* t* 1000)
    (land-u* (plains desert river) 1)
    (land-u* road 0)
    ((infantry paratroops germinator engineers) swamp 2)
    ((infantry paratroops germinator engineers) forest 2)
    ((infantry paratroops germinator engineers) mountains 2)
    ((infantry paratroops engineers) glaciers 1)
    ((infantry marines paratroops) river 0)
    (marines (coast lake swamp) 1)
    (marines sea 2)     ; Amphib assault ships.
    (aaa (forest mountains) 3)
    (engineers (coast lake) 2)
    (sea-u* (sea coast lake) 1)
    (air-u* t* 1)
    (air-u* (road river) 0)
    (landmines (append land-t* road) 1)
    (seamines water-t* 1)
    (u* barrier 1000)	; NOTE: Keep this entry at end of table.
)

(table mp-to-leave-terrain
    ; Default: 0
    ; Prevent units from crossing illegal terrain.
    (land-u* (swamp forest mountains glaciers) 1000)
    ((infantry paratroops marines) swamp 0)
    ((infantry paratroops aaa germinator engineers) forest 0)
    ((infantry paratroops aaa germinator engineers) mountains 0)
    ((infantry paratroops engineers) glaciers 0)
    ; Some units cannot move once they have made contact with a cell.
    ((landmines seamines) t* 1000)
)

(table mp-to-traverse
    ; Default: -1
;    (u* (river road) 1000)
    (land-u* road 1)
    ((torp-boats patrol-ship) river 2)
;    (air-u* road 1)
)

(table zoc-into-terrain
    ; Default: true
    ((cargo-planes spy-planes) t* false)
)

(table material-to-move
    ; Default: 0
    (u* supplies 1)
    (air-u* supplies 0)
    ; NOTE: The rest is just a copy of table consumption-to-move.
    ;  This is necessary because consumption-per-move is not a safeguard 
    ;  against movement with insufficient supplies. Indeed, Xconq resets 
    ;  any post-movement negative balances to 0. See kernel/move.c and 
    ;  um_consumption_per_move for details.
    (land-u* fuel1 1)
    ((infantry paratroops) fuel1 0)
    (sea-u* fuel2 1)
    (air-u* fuel1 1)
    (u* cnc 1)
    (facility-u* m* 0)
    (mine-u* m* 0)
)

(table consumption-per-move
    ; Default: 0
    (land-u* fuel1 1)
    ((infantry paratroops) fuel1 0)
    (sea-u* fuel2 1)
    (air-u* fuel1 1)
    (u* cnc 1)
    (facility-u* m* 0)
    (mine-u* m* 0)
)

(table consumption-on-creation
    ; Default: 0
    (u* cnc 5)
    ((town citadel) supplies 900)
    (forts supplies 3)
    ((base shipyard) supplies 10)
    (land-u* supplies 8)
    ((infantry paratroops) supplies 6)
    ((field-hq engineers) supplies 9)
    (transports supplies 17)
    ((torp-boats destroyer) supplies 3)
    (patrol-ship supplies 2)
    (frigate supplies 4)
    ((cruiser ecarrier) supplies 5)
    ((ccruiser submarine) supplies 6)
    ((battleship lcarrier) supplies 7)
    (carrier supplies 12)
    ((cargo-planes bombers) supplies 8)
    ((fighters dive-bombers torp-bombers spy-planes) supplies 3)
    (efighters supplies 5)
    (mine-u* supplies 2)
    ((base shipyard) equipment 7)
    (infantry equipment 2)
    ((mechinf marines armor aaa artillery) equipment 4)
    ((cavalry field-hq engineers) equipment 5)
    (paratroops equipment 3)
    (sea-u* equipment 4)
    ((cruiser ecarrier) equipment 5)
    ((transports ccruiser) equipment 6)
    ((battleship lcarrier submarine) equipment 7)
    (carrier equipment 9)
    (air-u* equipment 4)
    ((cargo-planes bombers spy-planes) equipment 6)
    ((mechinf marines armor) vehicles 4)
    (aaa vehicles 1)
    (artillery vehicles 3)
    (air-u* vehicles 4)
    (cargo-planes vehicles 16)
    ((cavalry field-hq engineers) vehicles 5)
    (land-u* recruits 4)
    (cavalry recruits 3)
    (field-hq recruits 5)
    (germinator recruits 0)
    (sea-u* recruits 1)
    (transports recruits 15)
    ((cruiser ccruiser ecarrier) recruits 2)
    (battleship recruits 4)
    (lcarrier recruits 5)
    (carrier recruits 10)
    (bombers recruits 1)
    (cavalry pilots 1)
    (cargo-planes pilots 10)
    ((fighters dive-bombers torp-bombers spy-planes) pilots 1)
    (efighters pilots 2)
    (bombers pilots 3)
    ((town citadel) cnc 150)
    (field-hq cnc 10)
    (germinator cnc 50)
    ((ccruiser battleship carrier) cnc 10)
    ((town citadel) settlers 100)
    ((ruins metropolis) m* 0)
)

(table supply-on-creation
    ; Default: 0
)

(table consumption-per-build
    ; Default: 0
    (u* cnc 2)
    (town supplies 10)
    (citadel supplies 20)
    (forts supplies 3)
    ((base shipyard) supplies 10)
    (land-u* supplies 5)
    ((infantry paratroops) supplies 4)
    ((cavalry field-hq engineers) supplies 6)
    (transports supplies 17)
    ((torp-boats destroyer) supplies 3)
    (patrol-ship supplies 2)
    (frigate supplies 4)
    ((cruiser ecarrier) supplies 5)
    ((ccruiser submarine) supplies 6)
    ((battleship lcarrier) supplies 7)
    (carrier supplies 12)
    ((cargo-planes bombers) supplies 8)
    ((fighters dive-bombers torp-bombers spy-planes) supplies 3)
    (efighters supplies 5)
    (mine-u* supplies 2)
    ((town citadel) cnc (20 30))
    ((base shipyard) cnc 20)
    (field-hq cnc 5)
    (germinator cnc 20)
    ((ccruiser battleship carrier) cnc 5)
    ((ruins metropolis) m* 0)
)

(table supply-on-completion
    ; Default: 0
;    ((town citadel) city-points (100 300))
)

(table attack-terrain-effect
    ; Default: 100
    (land-u* swamp 25)
    ((infantry paratroops) swamp 75)
    (marines swamp 100)
    (land-u* (forest mountains glaciers) 150)
)

(table fire-attack-terrain-effect
    ; Default: Lookup attack-terrain-effect
    (land-u* (mountains glaciers) 200)
)

(table defend-terrain-effect
    ; Default: 100
    (land-u* swamp 200)
    ((infantry marines paratroops) swamp 75)
    ((append facility-u* land-u*) (forest mountains glaciers) 25)
    (forts (mountains glaciers) 10)
    (land-u* road 300)
)

(table fire-defend-terrain-effect
    ; Default: Lookup defend-terrain-effect
    (land-u* swamp 150)
    ((infantry paratroops) swamp 50)
    (marines swamp 100)
    ((append facility-u* land-u*) (forest mountains glaciers) 25)
    (forts (mountains glaciers) 10)
    (land-u* road 300)
)

(table consumption-per-fire
    ; Default: 0
    (u* cnc 1)
    (ruins m* 0)
    (mine-u* m* 0)
)

(table consumption-per-attack
    ; Default: 0
    (land-u* fuel1 1)
    ((infantry paratroops) fuel1 0)
    (sea-u* fuel2 1)
    (air-u* fuel1 1)
    (u* cnc 2)
    (ruins m* 0)
    (shipwreck m* 0)
    (mine-u* m* 0)
)

; Enables material ("ammo") consumption for both firing and attacking.
(table hit-by
    ; Default: 0
    (u* cnc 1)
    (u* fuel1 1)
    (u* fuel2 1)
)

(table people-surrender-chance
    ; Default: 0
    (facility-u* land-t* 100)
    (infantry land-t* 75)
    (mechinf land-t* 80)
    (cavalry land-t* 50)
    (armor land-t* 100)
    (marines land-t* 80)
    (paratroops land-t* 80)
    (artillery land-t* 75)
    (aaa land-t* 50)
    (field-hq land-t* 100)
    (landmines land-t* 50)
)

(table material-to-repair
    ; Default: 0
)

(table consumption-per-repair
    ; Default: 0
    (u* supplies 2.0)
    (u* cnc 2.0)
    (facility-u* supplies 7.5)
    ((cavalry field-hq engineers) supplies 2.5)
    (air-u* supplies 2.5)
    (facility-u* equipment 5.0)
    (land-u* equipment 1.0)
    ((cavalry field-hq engineers) equipment 1.5)
    (sea-u* equipment 1.0)
    ((ccruiser battleship lcarrier carrier submarine) equipment 2.0)
    (air-u* equipment 1.0)
    (land-u* recruits 1.25)
    ((cavalry armor) recruits 0.25)
    (germinator recruits 0)
    (sea-u* recruits 1.0)
    ((battleship lcarrier carrier) recruits 1.5)
    (cavalry pilots 0.1)
    (air-u* pilots 0.5)
    (ruins m* 0)
)

(table visibility
    ; Default: 100%
    (land-u* land-t* 75)
    (land-u* (swamp plains desert) 100)
    ((infantry paratroops) swamp 50)
    ((infantry paratroops) (plains desert) 75)
    (land-u* (mountains forest) 25)
    (land-u* road 300)
    ((marines engineers) coast 50)
    (forts (mountains forest) 50)
)

(table track-chance
    ; Default: 0ppdk
    (u* facility-u* 10000)
    (facility-u* u* 10000)
    (ruins u* 0)
    ((town forts) air-u* 3000)
    (land-u* land-u* 7500)
    (cavalry land-u* 10000)
    (germinator land-u* 5000)
    (air-u* land-u* 9000)
    (air-u* (infantry paratroops) 4000)
    (air-u* sea-u* 10000)
    (air-u* (torp-boats patrol-ship) 8000)
    (spy-planes u* 10000)
)

(table lose-track-chance
    ; Default: 0ppdk
    ((infantry paratroops) swamp 2500)
    (land-u* forest 1000)
    ((infantry paratroops) forest 7000)
    (land-u* mountains 500)
    ((infantry paratroops) mountains 6000)
    ((infantry paratroops) glaciers 1000)
)

(table material-to-change-type
    ; Default: 0
)
